@@ -1,20 +1,20 @@
-from abc import ABC
+from dataclasses import field
+from typing import List, Union, Dict
+
+import github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2 as catalog_pb
+import github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2 as data_pb
+import github.com.metaprov.modelaapi.services.common.v1.common_pb2 as common_pb
+from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2 import Stakeholder, PermissionsSpec
+
 import modela.data.common as data_common
+from modela.Configuration import *
+from modela.common import *
+from modela.common import Plot
 from modela.data.common import *
 from modela.infra.Account import Account
 from modela.infra.UserRoleClass import UserRoleClass
 from modela.infra.models import Workload, NotificationSettings, OutputLogs, GitSettings, ImageLocation
 from modela.training.common import *
-from modela.common import *
-from modela.Configuration import *
-from dataclasses import field
-from typing import List, Union, Dict
-from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2 import CompilerSpec, Stakeholder, PermissionsSpec
-import github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2 as catalog_pb
-import github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2 as data_pb
-import github.com.metaprov.modelaapi.services.common.v1.common_pb2 as common_pb
-from modela.common import Plot
-from modela.util import TrackedList
 
 
 @datamodel(proto=data_pb.DataLocation)
@@ -305,6 +305,11 @@ class ExcelNotebookFormat(Configuration):
     Data: ExcelSheetArea = ExcelSheetArea()
     """ The specification for the bounds of the data """
 
+@datamodel(proto=data_pb.ParquetFileSpec)
+class ParquetFileFormat(Configuration):
+    Engine: str = ''
+    """ The name of the engine that exists in the excel file to read data from """
+
 
 @datamodel(proto=data_pb.Column)
 class Column(Configuration):
@@ -429,98 +434,22 @@ class RecommendationSchema(Configuration):
     """ The name of the column that specifies ratings """
 
 
-@datamodel(proto=data_pb.MultiDatasetTest)
-class MultiDatasetTest(Configuration):
-    """ MultiDatasetTestName specifies a test between multiple datasets """
-    Type: MultiDatasetTestName = None
-    """ The type of test """
-    Datasets: List[str] = field(default_factory=lambda : [])
-    """ The list of datasets that will be checked """
-    Generated: bool = False
-    """ Indicates if this test was automatically generated by the system """
-
-
-@datamodel(proto=data_pb.DatasetTest)
-class DatasetTest(Configuration):
-    """ DatasetTestName specifies a test for the contents of an entire dataset """
-    Type: DatasetTestName = None
-    """ The type of test """
-    Value: float = 0
-    Min: float = 0
-    Max: float = 0
-    ValueSet: List[str] = field(default_factory=lambda : [])
-    StrictMin: bool = False
-    StrictMax: bool = False
-    Generated: bool = False
-    """ Indicates if this test was automatically generated by the system """
-
-
-@datamodel(proto=data_pb.MultiColumnTest)
-class MultiColumnTest(Configuration):
-    """ MultiColumnTest specifies a test that encompasses multiple columns """
-    Type: MultiColumnTestName = None
-    """ The type of test  """
-    Columns: List[str] = field(default_factory=lambda : [])
-    """ The list of columns that will be checked """
-    Value: float = 0
-    Min: float = 0
-    Max: float = 0
-    ValueSet: List[str] = field(default_factory=lambda : [])
-    StrictMin: bool = False
-    StrictMax: bool = False
-    Generated: bool = False
-    """ Indicates if this test was automatically generated by the system """
-
-
-@datamodel(proto=data_pb.ColumnTest)
-class ColumnTest(Configuration):
-    """ ColumnTest specifies a test rule for a single column """
-    Type: ColumnTestName = None
-    """ The type of test """
-    Column: str = ''
-    """ The name of the column to be validated """
-    Value: float = 0
-    Min: float = 0
-    Max: float = 0
-    ValueSet: List[str] = field(default_factory=lambda : [])
-    StrictMin: bool = False
-    StrictMax: bool = False
-    Generated: bool = False
-    """ Indicates if this test was automatically generated by the system """
-
-
-@datamodel(proto=data_pb.FileTest)
-class FileTest(Configuration):
-    Type: FileTestName = None
-    BucketName: str = ''
-    Column: str = ''
-    Value: float = 0
-    """ For tests that need a single value """
-    Min: float = 0
-    Max: float = 0
-    ValueSet: List[str] = field(default_factory=lambda : [])
-    StrictMin: bool = False
-    StrictMax: bool = False
-    Generated: bool = False
-    """ Generated indicate weather this test was automatically generated """
-
-
-@datamodel(proto=data_pb.TestSpec)
-class Tests(Configuration):
-    MultiDatasetTests: List[MultiDatasetTest] = field(default_factory=lambda : [])
-    DatasetTests: List[DatasetTest] = field(default_factory=lambda : [])
+@datamodel(proto=data_pb.DatasetTestSuite)
+class DatasetTestSuite(Configuration):
+    MultiDatasetTests: TestSuite = TestSuite()
+    DatasetTests: TestSuite = TestSuite()
     """ DatasetTests contains tests for the whole dataset """
-    MultiColumnTests: List[MultiColumnTest] = field(default_factory=lambda : [])
+    MultiColumnTests: TestSuite = TestSuite()
     """ MultiColumnTests defines tests for multiple columns from the dataset """
-    ColumnTests: List[ColumnTest] = field(default_factory=lambda : [])
+    ColumnTests: TestSuite = TestSuite()
     """ ColumnTests defines assertions for columns from the dataset """
-    FileTests: List[FileTest] = field(default_factory=lambda : [])
+    FileTests: TestSuite = TestSuite()
     """ FileTests defines assertions for the contents of the data file """
 
 
 MDTimeSeriesSchema = TimeSeriesSchema
 MDRecommendationSchema = RecommendationSchema
-MDTests = Tests
+
 
 @datamodel(proto=data_pb.Schema)
 class Schema(Configuration):
@@ -531,7 +460,7 @@ class Schema(Configuration):
     """ The time-series schema, which sets time-series specific parameters """
     RecommendationSchema: MDRecommendationSchema = None
     """ The recommendation schema, which is used for the recommendation ML task """
-    Tests: MDTests = MDTests()
+    TestTemplate: DatasetTestSuite = DatasetTestSuite()
     """ The specification for test rules which will be performed on new Datasets """
 
 
@@ -568,6 +497,7 @@ class FlatFileFormat(Configuration):
     """ The file format for CSV files, if applicable """
     Excel: ExcelNotebookFormat = ExcelNotebookFormat()
     """ The file format for Excel files, if applicable """
+    Parquet:ParquetFileFormat = ParquetFileFormat()
 
 
 DataSourceSchema = Schema
@@ -684,6 +614,14 @@ class DatasetSpec(Configuration):
     Indicates if the Dataset should be quickly processed.
     If enabled, the validation, profiling, and reporting phases will be skipped.
     """
+    PredictionDatasetRef: ObjectReference = ObjectReference()
+    """
+    Prediction dataset ref is a reference to a prediction dataset ref (dataset that contain the predictions log).
+    """
+    PredictorRef: ObjectReference = ObjectReference()
+    """
+    Used for prediction dataset, contain a reference to the predictor resource that created this dataset
+    """
 
 
 @datamodel(proto=data_pb.OutlierStat)
@@ -907,12 +845,6 @@ class DatasetCondition(Configuration):
     """ A human readable message indicating details about the transition. """
 
 
-@datamodel(proto=data_pb.DataTestResult)
-class DataTestResult(Configuration):
-    Type: str = ''
-    Column: str = ''
-    Error: str = ''
-    Passed: bool = False
 
 
 @datamodel(proto=data_pb.DatasetStatus)
@@ -935,7 +867,7 @@ class DatasetStatus(ImmutableConfiguration):
     """ Whether or not the data was detected as imbalanced """
     ObservedGeneration: int = 0
     """ ObservedGeneration is the last generation that was acted on """
-    TestResults: List[DataTestResult] = field(default_factory=lambda : [])
+    TestResults: TestSuiteResult = TestSuiteResult()
     """ List of test results which are generated for every test associated with the Dataset's Data Source """
     LastStudyTime: Time = None
     """ Last time the Dataset was used with a Study """
