@@ -4,12 +4,13 @@ import github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2 as
 import github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.generated_pb2 as inference_pb
 from github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2 import *
 from modela.Configuration import datamodel
-from modela.common import Configuration, ConditionStatus, Time, ObjectReference, StatusError, TriggerScheduleEventType
-from modela.inference.common import PredictorConditionType, CanaryMetric, AccessType, PredictorType, ModelDeploymentPhase, ModelRole
+from modela.common import Configuration, ConditionStatus, Time, ObjectReference, StatusError, TriggerScheduleEventType, \
+    TestSuite, TestSuiteResult
+from modela.inference.common import PredictorConditionType, AccessType, PredictorType, ModelDeploymentPhase, ModelRole
 from modela.infra.models import Workload
 from modela.data.models import DataLocation
 from modela.training.common import TaskType
-from modela.training.models import ModelTest, ModelTestResult
+from modela.common import Metric
 
 
 @datamodel(proto=catalog_pb.RunSchedule)
@@ -61,7 +62,7 @@ class ModelDeploymentStatus(Configuration):
     """ Indicates if a data drift has been detected based on incoming prediction data """
     ConceptDrift: bool = False
     """ Indicates if a concept drift has been detected based on incoming prediction data """
-    LastDailyPredictions: List[int] = field(default_factory=lambda : [])
+    LastDailyPredictions: List[int] = field(default_factory=lambda: [])
     """ The predictions from the last 7 days """
 
 
@@ -87,7 +88,7 @@ class PredictorletStatus(Configuration):
     """ The total number of predictions served by the Predictorlet """
     LastFailure: str = ''
     """ LastFailure contains the last failure that occured with a model served by the Predictorlet """
-    LastDailyPredictions: List[int] = field(default_factory=lambda : [])
+    LastDailyPredictions: List[int] = field(default_factory=lambda: [])
     """ The predictions from the last 7 days """
 
 
@@ -133,7 +134,7 @@ class ModelDeploymentSpec(Configuration):
     """ MountTar means that we would mount the model tar file. Else we would use baked image. """
     TrafficSelector: str = ''
     """ TrafficSelector is a filter on the traffic to this model """
-    CanaryMetrics: List[CanaryMetric] = field(default_factory=lambda : [])
+    CanaryMetrics: List[Metric] = field(default_factory=lambda: [])
     """ If the deployment is canary, the metric define how to evaluate the canary """
     ApprovedBy: str = ''
     """ The account name of the approver """
@@ -163,7 +164,7 @@ class ProgressiveSpec(Configuration):
     """ The time, in seconds, for the warm-up period """
     TrafficIncrement: int = 0
     """ The percentage of traffic to increment """
-    CanaryMetrics: List[CanaryMetric] = field(default_factory=lambda : [])
+    CanaryMetrics: List[Metric] = field(default_factory=lambda: [])
     """ What metric to use when comparing the candidate model to the current model """
 
 
@@ -211,20 +212,54 @@ class AutoScalingSpec(Configuration):
     """
 
 
+@datamodel(proto=inference_pb.PredictionCacheStatus)
+class PredictionCacheStatus(Configuration):
+    LastAccessed: Time = None
+
+
+@datamodel(proto=inference_pb.OnlineStoreStatus)
+class OnlineStoreStatus(Configuration):
+    LastAccessed: Time = None
+
+
+@datamodel(proto=inference_pb.FeedbackTestStatus)
+class FeedbackTestStatus(Configuration):
+    Results: TestSuiteResult = TestSuiteResult()
+
+    LastRun: Time = None
+
+
+@datamodel(proto=inference_pb.DriftDetectionStatus)
+class DriftDetectionStatus(Configuration):
+    Results: TestSuiteResult = None
+    """ The drift detection test results """
+    LastRun: Time = None
+    """ Last time we performed the last run """
+
 @datamodel(proto=inference_pb.PredictorStatus)
 class PredictorStatus(Configuration):
     """ PredictorStatus contain the current state of the Predictor resource """
     ObservedGeneration: int = 0
     """ ObservedGeneration is the last generation that was acted on """
-    History: List[ModelRecord] = field(default_factory=lambda : [])
+    History: List[ModelRecord] = field(default_factory=lambda: [])
     """ The collection of historical records of models deployed to the Predictor, used internally to roll-back models """
-    Models: List[ModelDeploymentStatus] = field(default_factory=lambda : [])
+    Models: List[ModelDeploymentStatus] = field(default_factory=lambda: [])
     """ The collection of statuses for each model deployed with the Predictor """
     Predictorlet: PredictorletStatus = None
     """
     The status of the Predictorlet associated with the Predictor. The Predictorlet is a service which handles prediction traffic
     and routes predictions to individual models based on the specification of the Predictor
     """
+    CacheStatus: PredictionCacheStatus = None
+    """ Cache status is the status of the prediction cache """
+    OnlineStore: OnlineStoreStatus = OnlineStoreStatus()
+    """ Online store status status is the status of the prediction cache """
+    LastPredictionDataset: Time = None
+    """ Last time the the predictor perform a prediction"""
+    Feedback: FeedbackTestStatus = FeedbackTestStatus()
+    """ Ground Truth is the status of the ground truth tests """
+    Drift: DriftDetectionStatus = DriftDetectionStatus()
+    """ Drift is the status of the drift status"""
     LastUpdated: Time = None
     """ The last time the object was updated """
     EndPoint: str = ''
@@ -233,40 +268,43 @@ class PredictorStatus(Configuration):
     """ In the case of failure, the Predictor resource controller will set this field with a failure reason """
     FailureMessage: str = ''
     """ In the case of failure, the Predictor resource controller will set this field with a failure reason """
-    Conditions: List[PredictorCondition] = field(default_factory=lambda : [])
+    Conditions: List[PredictorCondition] = field(default_factory=lambda: [])
 
 
-@datamodel(proto=inference_pb.MonitorSpec)
-class MonitorSpec(Configuration):
-    """
-    MonitorSpec defines the specification to monitor a model in production
-    """
+@datamodel(proto=inference_pb.FeedbackTestSpec)
+class FeedbackTestSpec(Configuration):
     Enabled: bool = False
-    """ Indicates if model monitoring is enabled for the model """
-    SamplePercent: int = 0
-    """ The percentage of rows (0 through 100) of incoming data to sample for model monitoring """
+    """
+    Indicates if model monitoring is enabled for the model
+    """
+    GroundTrueDatasetRef: ObjectReference = None
+    """ The training dataset to use when calculated metrics """
+    TrainingDatasetRef: ObjectReference = None
+    """ The training dataset to use when calculated metrics """
+    Tests: TestSuite = TestSuite()
+    """ Test to run in order to calculate the predictor"""
     Schedule: RunSchedule = None
     """ The schedule on which model monitoring computations will be performed """
-    NotifierRef: ObjectReference = None
-    """ NotifierRef references a Notifier resource that will be triggered in the case that a concept or data drift is detected """
-    Tests: List[ModelTest] = field(default_factory=lambda : [])
+
+
+@datamodel(proto=inference_pb.DriftDetectionSpec)
+class DriftDetectionSpec(Configuration):
+    Enabled: bool = False
     """
-    tests contains the collection of model tests that will be 
-    performed based on incoming prediction traffic
+    Indicates if model monitoring is enabled for the model
     """
+    LiveHistogramRef: ObjectReference = None
+    """ The training dataset to use when calculated metrics """
+    TrainingHistogramRef: ObjectReference = None
+    """ The training dataset to use when calculated metrics """
+    Tests: TestSuite = TestSuite()
+    """ Test to run in order to calculate the predictor"""
+    Schedule: RunSchedule = None
+    """ The schedule on which model monitoring computations will be performed """
     OutlierDetectionModelRef: ObjectReference = None
     """ Reference to a model that will be used for outlier detection. If empty, an outlier detection model. """
 
 
-@datamodel(proto=inference_pb.MonitorStatus)
-class MonitorStatus(Configuration):
-    MonitorLastAttemptAt: Time = None
-    MonitorLastScore: float = 0
-    """ The score from the last time model monitoring was computed """
-    MonitorLastLatency: float = 0
-    """ The model latency from the last time model monitoring was computed """
-
-
 @datamodel(proto=inference_pb.PredictionLoggingSpec)
 class PredictionLoggingSpec(Configuration):
     """ PredictionLoggingSpec specifies the configuration to log incoming and outgoing prediction requests """
@@ -292,6 +330,82 @@ class ModelServingSpec(Configuration):
     """
 
 
+@datamodel(proto=inference_pb.ForwardCurtainSpec)
+class ForwardCurtainSpec(Configuration):
+    """ AccessSpec specifies the configuration to expose a Predictor service externally """
+    Enabled: bool = False
+    """
+    Is Forward curtain spec enabled
+    """
+    CurtainRef: ObjectReference = None
+    """
+    The forward curtain receives prediction requests before the prediction (currently unimplemented)
+    """
+    Percent: int = 0
+    """
+    Percent of request that are sent to the foreward curtain.
+    """
+
+
+@datamodel(proto=inference_pb.ForwardCurtainSpec)
+class BackwardCurtainSpec(Configuration):
+    """ AccessSpec specifies the configuration to expose a Predictor service externally """
+    Enabled: bool = False
+    """
+    Is Forward curtain spec enabled
+    """
+    CurtainRef: ObjectReference = None
+    """
+    The forward curtain receives prediction requests before the prediction (currently unimplemented)
+    """
+    ConfidenceLow: float = 0.4
+    """
+    For backward curtain is the confidence low
+    """
+    ConfidenceHigh: float = 0.6
+    """
+    For backward curtain is the confidence high
+    """
+
+
+@datamodel(proto=inference_pb.OnlineFeatureStoreSpec)
+class OnlineFeatureStoreSpec(Configuration):
+    """ AccessSpec specifies the configuration to expose a Predictor service externally """
+    Enabled: bool = False
+    """
+    Is online feature store enabled
+    """
+    HostName: str = ""
+    """
+    The forward curtain receives prediction requests before the prediction (currently unimplemented)
+    """
+
+
+@datamodel(proto=inference_pb.FastSlowModelSpec)
+class FastSlowModelSpec(Configuration):
+    """ AccessSpec specifies the configuration to expose a Predictor service externally """
+    Enabled: bool = False
+    """
+    Is fast slow enabled
+    """
+    FastModelRef: ObjectReference = None
+    """
+    Reference to the fast model
+    """
+    SlowModelRef: ObjectReference = None
+    """
+    Reference to the slow model
+    """
+    ProbaLowPct: int = 40
+    """
+    The low range of confidence.
+    """
+    ProbaHighPct: int = 60
+    """
+    The high range of confidence , Must be higher than probalow
+    """
+
+
 AccessType_ = AccessType
 
 
@@ -343,7 +457,7 @@ class PredictorSpec(Configuration):
     """ The reference to the DataProduct that the resource exists under """
     ServingsiteRef: ObjectReference = ObjectReference('default-tenant', 'default-lab')
     """ The reference to the ServingSite resource that hosts the Predictor """
-    Models: List[ModelDeploymentSpec] = field(default_factory=lambda : [])
+    Models: List[ModelDeploymentSpec] = field(default_factory=lambda: [])
     """
     The collection of model deployment specifications that define which Model resources will be deployed to the
     Predictor service and how they will be deployed. Each model should be trained with the same type of
@@ -375,12 +489,22 @@ class PredictorSpec(Configuration):
     """ Resources specifies the resource requirements allocated to the prediction service """
     Cache: PredictionCacheSpec = PredictionCacheSpec()
     """ Cache specifies the configuration of the prediction cache """
+    Store: OnlineFeatureStoreSpec = OnlineFeatureStoreSpec()
+    """ Store specify the connection to an online feature store """
+    ForwardCurtain: ForwardCurtainSpec = ForwardCurtainSpec()
+    """ Forward curtain specify the connection to a forward curtain """
+    BackwardCurtain: BackwardCurtainSpec = BackwardCurtainSpec()
+    """ Forward curtain specify the connection to a forward curtain """
     Task: TaskType = None
     """ The task type of the Predictor, which should match the task type of the models being served """
     PredictionThreshold: float = 0
     """ The prediction threshold """
-    Monitor: MonitorSpec = None
-    """ Monitor spec specify the monitor for this predictor. """
+    Drift: DriftDetectionSpec = DriftDetectionSpec()
+    """ Drift specify the drift detection settings"""
+    Feedback: FeedbackTestSpec = FeedbackTestSpec()
+    """ Feedback specify how to assign feedback files """
+    FastSlow: FastSlowModelSpec = FastSlowModelSpec()
+    """ Fast Slow define the configuration of fast slow models """
 
 
 @datamodel(proto=ProbabilityValue)
@@ -400,8 +524,42 @@ class PredictionResult(Configuration):
     Success: bool = False
     Score: float = 0
     Label: str = ''
-    Probabilities: List[ProbabilityValue] = field(default_factory=lambda : [])
-    ShapValues: List[ShapValue] = field(default_factory=lambda : [])
-    MissingColumns: List[str] = field(default_factory=lambda : [])
-    OutOfBound: List[str] = field(default_factory=lambda : [])
+    Probabilities: List[ProbabilityValue] = field(default_factory=lambda: [])
+    ShapValues: List[ShapValue] = field(default_factory=lambda: [])
+    MissingColumns: List[str] = field(default_factory=lambda: [])
+    OutOfBound: List[str] = field(default_factory=lambda: [])
     BaseShapValue: float = 0
+
+
+@datamodel(proto=inference_pb.BackwardCurtainSpec)
+class BackwardCurtainSpec(Configuration):
+    """ AccessSpec specifies the configuration to expose a Predictor service externally """
+    Port: int = 0
+    """
+    The port number that will be exposed on the Predictor's Pods to serve prediction traffic through the GRPCInferenceService API.
+    The Kubernetes Service created by the Predictor will expose the port and forward GRPC traffic to the backend pods
+    """
+    NodePort: int = 0
+    """
+    The port number that will be exposed on the external address of every node on the cluster, in the case of the
+    Predictor's access type being NodePort. Traffic from the port will be forwarded to the Predictor's backend service
+    """
+    Path: str = 0
+    """
+    The auto-generated DNS path where the Predictor service can be accessed. If the access type is ClusterIP, it will
+    be a cluster-internal DNS name (i.e. predictor.default-serving-site.svc.cluster.local). In the case of the Ingress
+    access type, it will be determined by the FQDN of the host ServingSite (i.e. predictor.default-serving-site.your-domain.ai).
+    """
+    AccessType: AccessType_ = AccessType_.ClusterIP
+    """
+    The Kubernetes-native access method which specifies how the Kubernetes Service created by the Predictor will be exposed.
+    See https://modela.ai/docs/docs/serving/production/#access-method for a detailed description of each access type
+    (defaults to cluster-ip)
+    """
+    Rest: bool = False
+    """
+    Indicates if the prediction service should expose an additional port to serve the GRPCInferenceService API through REST.
+    The port one digit above the number specified by the Port field will be exposed to accept HTTP/1.1 traffic
+    """
+    ApikeySecretRef: ObjectReference = None
+    """ ApiKeySecretRef references a Kubernetes Secret containing an API key that must be passed in prediction requests to the Predictor """
